spannertools
============

.. automodule:: abjad.tools.spannertools

.. only:: html

   Abstract classes
   ----------------

   .. autosummary::

      ~abjad.tools.spannertools.DirectedSpanner.DirectedSpanner.DirectedSpanner
      ~abjad.tools.spannertools.Spanner.Spanner.Spanner

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.spannertools.BeamSpanner.BeamSpanner.BeamSpanner
      ~abjad.tools.spannertools.BracketSpanner.BracketSpanner.BracketSpanner
      ~abjad.tools.spannertools.ComplexBeamSpanner.ComplexBeamSpanner.ComplexBeamSpanner
      ~abjad.tools.spannertools.ComplexGlissandoSpanner.ComplexGlissandoSpanner.ComplexGlissandoSpanner
      ~abjad.tools.spannertools.CrescendoSpanner.CrescendoSpanner.CrescendoSpanner
      ~abjad.tools.spannertools.DecrescendoSpanner.DecrescendoSpanner.DecrescendoSpanner
      ~abjad.tools.spannertools.DuratedComplexBeamSpanner.DuratedComplexBeamSpanner.DuratedComplexBeamSpanner
      ~abjad.tools.spannertools.DynamicTextSpanner.DynamicTextSpanner.DynamicTextSpanner
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner
      ~abjad.tools.spannertools.HairpinSpanner.HairpinSpanner.HairpinSpanner
      ~abjad.tools.spannertools.HiddenStaffSpanner.HiddenStaffSpanner.HiddenStaffSpanner
      ~abjad.tools.spannertools.HorizontalBracketSpanner.HorizontalBracketSpanner.HorizontalBracketSpanner
      ~abjad.tools.spannertools.MeasuredComplexBeamSpanner.MeasuredComplexBeamSpanner.MeasuredComplexBeamSpanner
      ~abjad.tools.spannertools.MultipartBeamSpanner.MultipartBeamSpanner.MultipartBeamSpanner
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner.OctavationSpanner
      ~abjad.tools.spannertools.PhrasingSlurSpanner.PhrasingSlurSpanner.PhrasingSlurSpanner
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner.PianoPedalSpanner
      ~abjad.tools.spannertools.SlurSpanner.SlurSpanner.SlurSpanner
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner.StaffLinesSpanner
      ~abjad.tools.spannertools.TextScriptSpanner.TextScriptSpanner.TextScriptSpanner
      ~abjad.tools.spannertools.TextSpanner.TextSpanner.TextSpanner
      ~abjad.tools.spannertools.TieSpanner.TieSpanner.TieSpanner
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.spannertools.make_dynamic_spanner_below_with_nib_at_right.make_dynamic_spanner_below_with_nib_at_right
      ~abjad.tools.spannertools.make_solid_text_spanner_with_nib.make_solid_text_spanner_with_nib
